@@ -333,7 +333,7 @@ def _log_exception(exception, exit=False) -> None:
     - exit: Boolean of whether or not to exit the program
     """
     if log.level >= logging.DEBUG:  # If we are debugging at all
-        log.warning('An exception was thrown and is logged below')
+        log.critical('An exception was thrown and is logged below')
         log.exception(exception)
     if exit:
         sys.exit()
@@ -663,6 +663,28 @@ def _print_commands(parsed_args: argparse.Namespace,
         print()
 
 
+def _check_for_key(listofdicts: list, key: str) -> bool:
+    """
+    Check for the existance of a key in a list of dicts. Throw a warning (once)
+        if it doesn't exist at all.
+    Used by _object_filter to check if filter keys exist if data to be
+        filtered.
+
+    - listofdicts: List of dictionary objects where each dictionary is a series
+        of attributes which can be matched against and filtered. Example:
+        [{'id': '1', 'name': 'THING1'}, {'id': '2', 'name': 'THING2'}]
+
+    - key: String of the dict key we are searching for.
+    """
+    if type(key) is not str:
+        raise Exception(f'Key ({key}) is not a string.')
+    for d in listofdicts:
+        if key in d:
+            return True
+    log.warning(f'Key "{key}" does not exist in data. Possible typo.')
+    return False
+
+
 def _object_filter(listofdicts: list, filter_strs: list,
                    and_logic=False) -> []:
     """
@@ -674,9 +696,8 @@ def _object_filter(listofdicts: list, filter_strs: list,
         [{'id': '1', 'name': 'THING1'}, {'id': '2', 'name': 'THING2'}]
     - filter_strs: List of strings which are filter definitions. Example:
         ['name:^m...$', 'id:10...']
-    - and_logic: Boolean of whether or not to use "AND" between filters or to
-        use "OR" as is default.
-
+    - and_logic: Boolean of whether or not to use "AND" between filters.
+         Using "OR" is the default.
     """
     log.debug(f'Starting item filter. Using "AND" logic: {and_logic}')
     # Return the data if it is not a list. We can't filter just one.
@@ -687,16 +708,27 @@ def _object_filter(listofdicts: list, filter_strs: list,
         return listofdicts  # Return it back since it can't be filtered
     filters = []  # Build list of dicts for filter definitions.
     for filter_str in filter_strs:  # Iterate user provided strings to parse
-        # Extract the key name up to the colon
-        key = re.search('^[a-zA-Z0-9].*?:', filter_str).group(0)
+        try:  # Catch exceptions to better
+            # Extract the key name up to the colon
+            key = re.search('^[a-zA-Z0-9].*?:', filter_str).group(0)
+        except AttributeError:
+            log.error(f'Malformed filter statement: "{filter_str}"')
+            sys.exit(1)
         # Grab the remaining string for the regex
         regex = filter_str[len(key):]
         key = key.replace(':', '')
-        # If the provided filter key is not in the object attributes
-        if key not in listofdicts[0]:
-            raise KeyError(f'Filter key "{key}" does not exist in data')
         filters.append({'key': key, 'regex': regex})
     log.debug(f'Built regex filters:\n{json.dumps(filters, indent=4)}')
+    key_checks = []  # List of checks we can use for an AND-logic check
+    for fdict in filters:
+        # Run the check and add the result to the key_checks list
+        key_checks.append(_check_for_key(listofdicts, fdict['key']))
+    # If we are using AND logic and there was a single key check failure
+    if and_logic and False in key_checks:
+        # Throw a warning and return an empty result
+        log.warning(
+            'Detected missing filter keys, returning empty object list')
+        return []
     result = []
     # Perform the actual filtering now. The 'fdict' variable will be a filter
     #     definition in dict form. Example:
@@ -705,6 +737,10 @@ def _object_filter(listofdicts: list, filter_strs: list,
         # Use enumerate and an index so we can track how many of the filters
         #     have passed so far. This is used for the "AND" logic filtering
         for index, fdict in enumerate(filters):
+            # If the filter key is not in the object to be filtered
+            if fdict['key'] not in item:
+                # Don't even perform the check, just fail the object
+                break
             # If our regex generates a match with the value of the attribute
             if re.search(fdict['regex'], str(item[fdict['key']])):
                 if and_logic:  # If we are using "AND" filter logic
@@ -1022,7 +1058,12 @@ def main(argstring=None) -> None:
                              action='help')
     basic_group.add_argument('-v', '--version',
                              version=f'Meraki-CLI v{__version__} | '
-                             f'Meraki API Library v{meraki.__version__}',
+                             f'Meraki API Library v{meraki.__version__} | '
+                             'Python {}.{}.{}'.format(
+                                sys.version_info[0],
+                                sys.version_info[1],
+                                sys.version_info[2],
+                             ),
                              action="version")
     basic_group.add_argument('-k', '--apiKey',
                              help='Meraki API Access Key',
